# A Tcl script for the Qsys system console

# Start Qsys, open your soc_system.qsys file, run File->System Console,
# then execute this script by selecting it with Ctrl-E

# The System Console is described in Chapter 10 of Volume III of
# the Quartus II Handbook

# Alternately,
# system-console --project_dir=. --script=syscon-test.tcl
#
# system-console --project_dir=. -cli
#   and then "source syscon-test.tcl"

# Base addresses of the peripherals: take from Qsys
#set vga_led 0x0
set audio 0x00040000

puts "Started system-console-test-script"

# Using the JTAG chain, check the clock and reset"

set j [lindex [get_service_paths jtag_debug] 0]
open_service jtag_debug $j
puts "Opened jtag_debug"

puts "Checking the JTAG chain loopback: [jtag_debug_loop $j {1 2 3 4 5 6}]"
jtag_debug_reset_system $j

puts -nonewline "Sampling the clock: "
foreach i {1 1 1 1 1 1 1 1 1 1 1 1} {
    puts -nonewline [jtag_debug_sample_clock $j]
}
puts ""

puts "Checking reset state: [jtag_debug_sample_reset $j]"

close_service jtag_debug $j
puts "Closed jtag_debug"

# Perform bus reads and writes

set m [lindex [get_service_paths master] 0]
open_service master $m
puts "Opened master"


set x 0
#while {$x < 256} {
	master_write_16 $m [expr $audio + $x] 0x1111
#	set x [expr {$x + 4}]
#}


# Write a test pattern to the various registers
#while {1} {

#	foreach {r v} {4100 0x00000001 4100 0x00000002 4100 0x00000003 4100 0x00000004 4100 0x00000005 4100 0x00000006 4100 0x00000007 4100 0x00000008 4100 0x00000009 4100 0x0000000a 4100 0x0000000b 4100 0x0000000c 4100 0x00000000} {
#		after 500
		#master_write_32 $m [expr $vga_led + $r] $v
		#master_write_32 $m [expr $vga_led + 4100] 0x00000002
#	}


#	foreach {r v} {4096 0x000a000a 4096 0x0064000a 4096 0x00640064} {
#		after 500
#		master_write_32 $m [expr $vga_led + $r] $v
#		master_write_32 $m [expr $vga_led + 4096] 0x00640064
#	}
#}

close_service master $m
puts "Closed master"




